.. image:: https://circleci.com/gh/krukas/Trionyx/tree/master.svg?style=svg
    :target: https://circleci.com/gh/krukas/Trionyx/tree/master
    
.. image:: https://readthedocs.org/projects/trionyx/badge/?version=latest
    :target: http://trionyx.readthedocs.io/en/latest

.. image:: https://codecov.io/gh/krukas/Trionyx/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/krukas/Trionyx

.. image:: https://badge.fury.io/py/Trionyx.svg
    :target: https://badge.fury.io/py/Trionyx
    

Trionyx
=======

Trionyx is an application framework for managing data and processes, or can be used as an glorified customer admin panel for Django.


.. image:: screenshots/dashboard.jpg

Installation
============
To install Trionyx, run:

    pip install Trionyx

Create new project
==================
For creating a new project, run:

    trionyx create_project new_project
